@@ -2,7 +2,7 @@ import ast
 import inspect
 import os
 from dataclasses import dataclass
-from typing import Callable, Optional
+from typing import Optional
 
 from . import globals
 
@@ -17,13 +17,13 @@ class Config():
     dark: Optional[bool] = False
     reload: bool = True
     show: bool = True
-    on_connect: Optional[Callable] = None
     uvicorn_logging_level: str = 'warning'
     uvicorn_reload_dirs: str = '.'
     uvicorn_reload_includes: str = '*.py'
     uvicorn_reload_excludes: str = '.*, .py[cod], .sw.*, ~*'
     main_page_classes: str = 'q-ma-md column items-start'
     binding_refresh_interval: float = 0.1
+    exclude: str = ''
     interactive: bool = False
 
 
