@@ -3,6 +3,7 @@ from typing import Callable, Optional
 import justpy as jp
 
 from ..events import ClickEventArguments, handle_event
+from ..task_logger import create_task
 from .element import Element
 
 
@@ -20,11 +21,11 @@ class MenuItem(Element):
         view = jp.QItem(text=text, clickable=True, temp=False)
 
         def handle_click(view, event) -> Optional[bool]:
-            socket = event.get('websocket')
-            result = handle_event(on_click, ClickEventArguments(sender=self, socket=socket), update=self.parent_view)
+            result = handle_event(on_click, ClickEventArguments(sender=self, socket=event.get('websocket')))
             if auto_close:
                 assert isinstance(self.parent_view, jp.QMenu)
                 self.parent_view.value = False
+                create_task(self.parent_view.update())
             return result
 
         view.on('click', handle_click)
