@@ -11,7 +11,7 @@ class Radio(ChoiceElement):
         """Radio Selection Element
 
         :param options: a list ['value1', ...] or dictionary `{'value1':'label1', ...}` specifying the options
-        :param value: the inital value
+        :param value: the initial value
         :param on_change: callback to execute when selection changes
         """
         view = jp.QOptionGroup(options=options, input=self.handle_change, temp=False)
