@@ -10,11 +10,15 @@ from .element import Element
 
 class Upload(Element):
 
-    def __init__(self, *, multiple: bool = False, on_upload: Optional[Callable] = None):
+    def __init__(self, *,
+                 multiple: bool = False,
+                 on_upload: Optional[Callable] = None,
+                 upload_button_text: str = 'Upload') -> None:
         """File Upload Element
 
         :param multiple: allow uploading multiple files at once (default: `False`)
         :param on_upload: callback to execute when a file is uploaded (list of bytearrays)
+        :param upload_button_text: text for the upload button
         """
         self.upload_handler = on_upload
         view = jp.Form(
@@ -23,8 +27,8 @@ class Upload(Element):
             submit=lambda sender, msg: self.submit(sender, msg),
             temp=False,
         )
-        jp.Input(type='file', multiple=multiple, a=view, temp=False)
-        jp.QBtn(type='submit', text='Upload', color='primary', a=view, temp=False)
+        jp.Input(type='file', multiple=multiple, change=lambda *_: False, a=view, temp=False)
+        jp.QBtn(type='submit', text=upload_button_text, color='primary', a=view, temp=False)
 
         super().__init__(view)
 
@@ -34,8 +38,8 @@ class Upload(Element):
             for form_data in msg.form_data:
                 if form_data.type == 'file':
                     files = [base64.b64decode(f.file_content) for f in form_data.files]
-                    arguments = UploadEventArguments(sender=self, files=files)
-                    if handle_event(self.upload_handler, arguments, update=self.parent_view) is None:
+                    arguments = UploadEventArguments(sender=self, socket=msg.websocket, files=files)
+                    if handle_event(self.upload_handler, arguments):
                         page_update = None
             return page_update
         except Exception:
