@@ -8,10 +8,8 @@ from .element import Element
 
 
 class ValueElement(Element):
-    value = BindableProperty(
-        on_change=lambda sender, value: handle_event(sender.change_handler,
-                                                     ValueChangeEventArguments(sender=sender, value=value),
-                                                     update=sender.parent_view))
+    value = BindableProperty(on_change=lambda sender, value: handle_event(
+        sender.change_handler, ValueChangeEventArguments(sender=sender, socket=None, value=value)))
 
     def __init__(self, view: jp.HTMLBaseComponent, *, value: Any, on_change: Optional[Callable]):
         super().__init__(view)
@@ -25,6 +23,8 @@ class ValueElement(Element):
 
     def handle_change(self, msg: Dict):
         self.value = msg['value']
+        self.update()
+        return False
 
     def bind_value_to(self, target_object, target_name, *, forward=lambda x: x):
         bind_to(self, 'value', target_object, target_name, forward=forward)
